CCL: /home/chisarie/Documents/lsst_ccl/CCL/include/ccl_utils.h Source File

CCL

ccl_utils.h
Go to the documentation of this file.
1
3 #pragma once
4
12 double * ccl_linear_spacing(double xmin, double xmax, int N);
13
14
22 double * ccl_log_spacing(double xmin, double xmax, int N);
23
ccl_log_spacing
double * ccl_log_spacing(double xmin, double xmax, int N)
Definition: ccl_utils.c:36
ccl_linear_spacing
double * ccl_linear_spacing(double xmin, double xmax, int N)
Definition: ccl_utils.c:12